require "./lib/rcloud.rb"


require "minitest/autorun"

class TestMeme < Minitest::Test


  USERA = "mockuser"	
  USERB = "mock_block"
  GROUPA = "mock_group"
  CHATROOMA = "1001"


  def setup
    @request = RCloud::Request.new("mgb7ka1nb5dfg", "krO8vJkvpu1yj")
    @request.user_gettoken(USERB)
    @user_id = nil
    @user_token = nil
  end

  # user

  def test_user_gettoken
  	# {"code":200, "USERA":"jlk456j5", "token":"sfd9823ihufi"}
  	resp = @request.user_gettoken(USERA)
  	@user_id = resp["user_id"]
  	@user_token = resp["token"]
    assert_equal 200, resp["code"]
  end

  def test_user_refresh
  	# {"code":200, "USERA":"jlk456j5", "token":"sfd9823ihufi"}
  	resp = @request.user_gettoken(USERA)
    assert_equal 200, resp["code"]
  end

  def test_user_checkonline
  	resp = @request.user_checkonline(USERA)
  	assert_equal 200, resp["code"]
  end	

  # block 

  def test_user_block
  	resp = @request.user_block(USERA, 1)
  	assert_equal 200, resp["code"]
  end

  def test_user_unblock
  	resp = @request.user_unblock(USERA)
  	assert_equal 200, resp["code"]
  end

  def test_user_block_query
  	resp = @request.user_block_query()
  	assert_equal 200, resp["code"]
  end

  # blacklist
  def test_user_blacklist_add
  	resp = @request.user_blacklist_add(USERA, USERB)
  	assert_equal 200, resp["code"]

  end

  def test_user_blacklist_remove
  	resp = @request.user_blacklist_remove(USERA, USERB)
  	assert_equal 200, resp["code"]
  end

  def test_user_blacklist_query
  	resp = @request.user_blacklist_query
  	assert_equal 200, resp["code"]
  end

  # Message

  def test_message_private_publish
  	resp = @request.message_private_publish(USERA, USERB, "RC:TxtMsg", JSON.generate({"content" => "hello", "extra" => "helloExtra"}))
   	assert_equal 200, resp["code"]
  end


  def test_message_system_publish
  	resp = @request.message_system_publish(USERA, USERB, "RC:TxtMsg", JSON.generate({"content" => "hello", "extra" => "helloExtra"}))
   	assert_equal 200, resp["code"]
  end

  def test_message_group_publish
    resp = @request.group_create(USERA, "1001", GROUPA)
    resp = @request.group_join(USERA, GROUPA)
    resp = @request.message_group_publish(USERA, "1001", "RC:TxtMsg", JSON.generate({"content" => "hello", "extra" => "helloExtra"}))
    assert_equal 200, resp["code"]
  end

  def test_message_chatroom_publish
    resp = @request.chatroom_create({CHATROOMA => GROUPA})
    resp = @request.message_chatroom_publish(USERA, CHATROOMA, "RC:TxtMsg", JSON.generate({"content" => "hello", "extra" => "helloExtra"}))
    assert_equal 200, resp["code"]
  end

  def test_message_broadcast
    resp = @request.message_broadcast(USERA, "RC:TxtMsg", JSON.generate({"content" => "hello", "extra" => "helloExtra"}))
    assert_equal 200, resp["code"]
  end
  # History

  def test_message_history
  	resp = @request.message_history(DateTime.now.strftime("%Y%m%d%H"))
  	assert_equal 200, resp["code"]
  end	

  def test_message_history_delete
  	resp = @request.message_history_delete("2015042523")
  	assert_equal 200, resp["code"]
  end

  # Group

  def test_group_sync #
  	resp = @request.group_create(USERA, "1001", GROUPA)
    assert_equal 200, resp["code"]

    resp = @request.group_sync(USERA, {"1001" => GROUPA})
    assert_equal 200, resp["code"]

  	resp = @request.group_sync(USERA)
    assert_equal 200, resp["code"]
  end

  def test_group_create
  	resp = @request.group_create([USERA, USERB], GROUPA, GROUPA)
   	assert_equal 200, resp["code"]
  end

  def test_group_join
  	resp = @request.group_join([USERA,USERB], GROUPA)
  	assert_equal 200, resp["code"]
  end

  def test_group_quit
  	resp = @request.group_quit([USERA, USERB], GROUPA)
    assert_equal 200, resp["code"]

  end

  def test_group_dismiss
  	resp = @request.group_dismiss(USERA, USERB)
    assert_equal 200, resp["code"]

  end

  def test_group_refresh #
  	resp = @request.group_refresh(GROUPA, GROUPA)
    assert_equal 200, resp["code"]

  end

  # ChatRoom

  def test_chatroom_create
    resp = @request.chatroom_create({CHATROOMA => GROUPA})
    assert_equal 200, resp["code"]
  end

  def test_chatroom_destroy
    resp = @request.chatroom_create({CHATROOMA => GROUPA})
    resp = @request.chatroom_create({"123" => GROUPA})    
    resp = @request.chatroom_destroy([CHATROOMA, "123"])
    assert_equal 200, resp["code"]
  end

  def test_chatroom_query
    resp = @request.chatroom_create({CHATROOMA => GROUPA})
    resp = @request.chatroom_query(GROUPA)
    assert_equal 200, resp["code"]
  end

  def test_chatroom_user_query
    resp = @request.chatroom_query(CHATROOMA)
    assert_equal 200, resp["code"]
  end



end

